AccessibilityScanner class

Main accessibility scanner that analyzes Flutter widget trees for accessibility issues.

Constructors

AccessibilityScanner()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(BuildContext context) Future<AccessibilityReport>
Scans the widget tree starting from the given context for accessibility issues. Returns an AccessibilityReport containing all detected issues.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited